@@ -308,9 +308,10 @@ class ComposeCLI(DockerCLICaller):
 
     def pull(
         self,
-        services: Optional[List[str]] = None,
+        services: Union[List[str], str, None] = None,
         ignore_pull_failures: bool = False,
         include_deps: bool = False,
+        quiet: bool = False,
     ):
         """Pull service images
 
@@ -321,16 +322,20 @@ class ComposeCLI(DockerCLICaller):
                 If an empty list is provided, then the function call is a no-op.
             ignore_pull_failures: Pull what it can and ignores images with pull failures
             include_deps: Also pull services declared as dependencies
+            quiet: By default, the progress bars are printed in stdout and stderr (both).
+                To disable all output, use `quiet=True`
 
         """
         full_cmd = self.docker_compose_cmd + ["pull"]
         full_cmd.add_flag("--ignore-pull-failures", ignore_pull_failures)
         full_cmd.add_flag("--include-deps", include_deps)
+        full_cmd.add_flag("--quiet", quiet)
         if services == []:
             return
         elif services is not None:
+            services = to_list(services)
             full_cmd += services
-        run(full_cmd)
+        run(full_cmd, capture_stdout=False, capture_stderr=False)
 
     def push(self, services: Optional[List[str]] = None):
         """Push service images
@@ -566,7 +571,7 @@ class ComposeCLI(DockerCLICaller):
 
     def up(
         self,
-        services: Optional[List[str]] = None,
+        services: Union[List[str], str, None] = None,
         build: bool = False,
         detach: bool = False,
         abort_on_container_exit: bool = False,
@@ -577,6 +582,7 @@ class ComposeCLI(DockerCLICaller):
         color: bool = True,
         log_prefix: bool = True,
         start: bool = True,
+        quiet: bool = False,
     ):
         """Start the containers.
 
@@ -605,6 +611,8 @@ class ComposeCLI(DockerCLICaller):
             color: If `False`, it will produce monochrome output.
             log_prefix: If `False`, will not display the prefix in the logs.
             start: Start the service after creating them.
+            quiet: By default, some progress bars and logs are sent to stderr and stdout.
+                Set `quiet=True` to avoid having any output.
 
         # Returns
             `None` at the moment. The plan is to be able to capture and stream the logs later.
@@ -627,8 +635,10 @@ class ComposeCLI(DockerCLICaller):
         if services == []:
             return
         elif services is not None:
+            services = to_list(services)
             full_cmd += services
-        run(full_cmd, capture_stdout=False)
+        # important information is written to both stdout AND stderr.
+        run(full_cmd, capture_stdout=quiet, capture_stderr=quiet)
 
     def version(self) -> str:
         """Returns the version of docker compose as a `str`."""
